icsemantic.catalog.criteria.related

Package platecom :: Package ontocatalog :: Package criteria :: Module related |
[hide private]
[frames] | no frames]

# Module related

source code

A friendly criterion for ATTopic that matches the SearchableRelatedText index parameters

Classes | [hide private]
| ATRelatedCriterion A related text criterion

Variables | [hide private]
| ATRelatedCriterionSchema = `ATBaseCriterionSchema+ Schema((Stri`...``

Variables Details | [hide private]

  ### ATRelatedCriterionSchema Value:
      ATBaseCriterionSchema+ Schema((StringField('value', required= 1, mode=
       "rw", write_permission= ChangeTopics, accessor= "Value", mutator= "se
      tValue", default= "", widget= StringWidget(label= _(u'label_related_cr
      iterion_value', default= u'Value'), description= _(u'help_related_crit
      erion_value', default= u'A string value.'))), StringField('context', r
      equired= 0, mode= "rw", write_permission= ChangeTopics, accessor= "Con
      text", mutator= "setContext", default= "", widget= StringWidget(label=
       _(u'label_related_criterion_value', default= u'Context'), description
      ...